static DH *get_dh512(void)
{
    static unsigned char dhp_512[] = {
        0xD9, 0xFE, 0x01, 0xC7, 0xC4, 0xED, 0x93, 0xF1, 0x8D, 0xA7,
        0xA4, 0x07, 0x92, 0x3E, 0x02, 0x34, 0x4F, 0x66, 0xAF, 0xE3,
        0x16, 0xF1, 0xD4, 0x25, 0x9D, 0x9A, 0xD4, 0xC4, 0x77, 0x67,
        0x0E, 0xB2, 0xE7, 0xFC, 0xE1, 0x28, 0x72, 0x63, 0xC9, 0xDE,
        0x57, 0xFB, 0x3A, 0x2E, 0x7C, 0xD4, 0xAC, 0xDD, 0xD7, 0x37,
        0xD4, 0x13, 0xB3, 0x2D, 0x91, 0x35, 0xC1, 0x13, 0x29, 0xBB,
        0xBE, 0xB6, 0x94, 0xC7
    };
    static unsigned char dhg_512[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_512, sizeof(dhp_512), NULL);
    g = BN_bin2bn(dhg_512, sizeof(dhg_512), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
static DH *get_dh2048(void)
{
    static unsigned char dhp_2048[] = {
        0xCD, 0x02, 0xB0, 0x5C, 0x6F, 0x71, 0xD6, 0xFD, 0x17, 0xA7,
        0x62, 0x36, 0x09, 0xC1, 0x24, 0xFB, 0xA3, 0xF3, 0xF1, 0x07,
        0xF2, 0x97, 0xAF, 0x2B, 0x82, 0xD4, 0xAF, 0x17, 0x59, 0xB0,
        0xA9, 0xB1, 0xEA, 0xA1, 0xC0, 0x87, 0x50, 0x04, 0xC5, 0x04,
        0x16, 0x65, 0x1A, 0xAC, 0x07, 0xCA, 0x87, 0xF8, 0xDD, 0xC7,
        0x2F, 0x46, 0xBC, 0xB7, 0x76, 0x38, 0xF6, 0x3F, 0xB9, 0x49,
        0x56, 0x4D, 0x22, 0x08, 0x09, 0xB5, 0xAD, 0x95, 0x7B, 0x53,
        0x97, 0x30, 0x81, 0x6E, 0xD0, 0xB2, 0x77, 0xE7, 0xB6, 0x2C,
        0x2D, 0xE3, 0x12, 0xD3, 0x43, 0xFF, 0x55, 0x00, 0x0D, 0x6F,
        0x1D, 0x52, 0x9B, 0xA4, 0x28, 0x7A, 0x7C, 0x98, 0xDD, 0x79,
        0xE9, 0x67, 0xB1, 0xB7, 0x14, 0xDA, 0xD9, 0x59, 0x2C, 0x4B,
        0x70, 0xF0, 0x52, 0x6B, 0x3D, 0x8A, 0x2E, 0x44, 0xEF, 0xAE,
        0x82, 0xD1, 0x17, 0x41, 0x3B, 0x6C, 0x22, 0x97, 0x8A, 0x8B,
        0x1C, 0x5A, 0x1B, 0x6A, 0xC8, 0x98, 0xBB, 0x72, 0x67, 0xCF,
        0x17, 0xF0, 0x86, 0x51, 0x2B, 0x8E, 0xE4, 0x91, 0xA3, 0xAE,
        0xC7, 0xEF, 0xC8, 0x8C, 0x2F, 0x5C, 0xB4, 0x9F, 0xDE, 0xA1,
        0x44, 0x86, 0x33, 0xBB, 0x3C, 0xE2, 0xD9, 0x6B, 0xBE, 0xD2,
        0xBC, 0xFD, 0x7D, 0x35, 0xFD, 0xA7, 0xE7, 0xA3, 0xF4, 0x1E,
        0x9D, 0x64, 0x31, 0xD3, 0x20, 0xED, 0xEF, 0x5A, 0x94, 0xBD,
        0xFD, 0x8D, 0x46, 0xF3, 0xFB, 0x1C, 0x47, 0x05, 0x2C, 0x18,
        0x39, 0x8C, 0xC5, 0x08, 0x4C, 0xF7, 0xAE, 0x27, 0x34, 0x40,
        0xF1, 0x50, 0xAB, 0x92, 0x89, 0xA3, 0x67, 0x9B, 0x69, 0xBD,
        0x3E, 0x9D, 0xF6, 0x1A, 0xEE, 0x6F, 0xAD, 0x16, 0x94, 0x3A,
        0xAF, 0x01, 0x7A, 0xA5, 0x78, 0x6E, 0x3B, 0x21, 0x45, 0xC1,
        0x0F, 0x76, 0x85, 0xF1, 0xD6, 0xBE, 0x6D, 0x44, 0xBB, 0x44,
        0x30, 0xC1, 0x29, 0xE2, 0xC9, 0x23
    };
    static unsigned char dhg_2048[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_2048, sizeof(dhp_2048), NULL);
    g = BN_bin2bn(dhg_2048, sizeof(dhg_2048), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
